<?php
/*
Plugin Name: Scan-to-Login
Plugin URI: 
Description: Scan-to-Login Wordpress Plugin.
Version: 1.4
Author: Scan-to-Login
Author URI: 
License: 
*/

class Scantologin {
    function enqueue_scripts() {
        wp_enqueue_script('jquery');
        wp_enqueue_script('zappertech', plugins_url('zappertech.js', __FILE__));
        wp_enqueue_script('bootstrap', home_url() . '/index.php?zappertech=bootstrap');
        wp_enqueue_style('scantologin', plugins_url('scantologin.css', __FILE__));
    }
    function hijack() {
        if(isset($_GET['zappertech'])) { 
            switch ($_GET['zappertech']) {
                case 'bootstrap':
                    include 'bootstrap.php';
                    break;
                case 'register':
                    $this->register_user();
                    break;
				case 'authenticate':
					$this->authenticate_user();
					break;
            }
            exit();
        }
    }
    function register_user() {
        $response = array();
        $firstName = sanitize_text_field($_POST['firstName']);
        $lastName = sanitize_text_field($_POST['lastName']);
        $email = sanitize_text_field($_POST['email']);
        $password = sanitize_text_field($_POST['password']);
        //Validation
        $response['errors'] = array();
        $response['success'] = FALSE;
        $response['username'] = '';
        $response['password'] = '';
        if(empty($firstName))
            $response['errors'][] = 'Please enter a first name.';
        if(empty($lastName))
            $response['errors'][] = 'Please enter a last name.';
        if(empty($email))
            $response['errors'][] = 'Please enter an email address.';
        if(username_exists($email))
            $response['errors'][] = 'Email address already registered.';
        if(empty($password))
            $response['errors'][] = 'Please enter a password.';
        //Registration
        if(empty($response['errors'])) {
            $userId = wp_create_user($email, $password, $email);
            if(is_wp_error($userId)) {
                $response['errors'][] = $userId->get_error_message();
            } else {
                wp_update_user(array(
                    'ID'    => $userId,
                    'first_name' => $firstName,
                    'last_name' => $lastName
                ));
                $response['success'] = TRUE;
                $response['username'] = $email;
                $response['password'] = $password;
            }
        }
        echo json_encode($response);
    }
	
	function authenticate_user()
	{
		$username = sanitize_text_field($_POST['username']);
        $password = sanitize_text_field($_POST['password']);
	
		$user = wp_authenticate_username_password(NULL, $username, $password);
		
		$response = array();
		$response['success'] = FALSE;
        $response['username'] = '';
        $response['password'] = '';
		
		if (is_wp_error($user))
		{
			$response['errors'] = $user;
			echo($response);
		}
		else
		{
			$response['success'] = TRUE;
			$response['username'] = $email;
			$response['password'] = $password;
			
			echo($response);
		}
	}
	
    function add_admin_menu() {
        add_options_page( 'Scan-to-Login Options', 'Scan-to-Login', 'manage_options', 'scantologin', array($this, 'admin_page'));
    }
    function admin_page_save($post) {
        $results = array(
            'errors' => array(),
            'merchantId' => 0,
            'siteId' => 0,
            'saved' => false,
            'scantologin_self_registration_allowed' => (isset($post['scantologin_self_registration_allowed']) ? 'true' : 'false'),
            'scantologin_demo_mode' => 'false'
        );  
        if(isset($post['scantologin_merchant_id'])) { 
            $results['merchantId'] = $post['scantologin_merchant_id'];
            if(!is_numeric($post['scantologin_merchant_id']) || $post['scantologin_merchant_id'] < 1)
                $results['errors'][] = 'Please enter a valid merchant id.';
        } else 
            $results['errors'][] = 'Please enter a valid merchant id.';
        if(isset($post['scantologin_site_id'])) { 
            $results['siteId'] = $post['scantologin_site_id'];
            if(!is_numeric($post['scantologin_site_id']) || $post['scantologin_site_id'] < 1)
                $results['errors'][] = 'Please enter a valid site id.';
        } else
            $results['errors'][] = 'Please enter a valid site id.';
        if(empty($results['errors'])) {
            update_option('scantologin_merchant_id', $results['merchantId']);
            update_option('scantologin_site_id', $results['siteId']);
            update_option('scantologin_self_registration_allowed', $results['scantologin_self_registration_allowed']);
            update_option('scantologin_demo_mode', $results['scantologin_demo_mode']);
            $results['saved'] = true;
        }
        return $results;
    }
    function admin_page() {
        $merchantId = get_option('scantologin_merchant_id', 0);
        $siteId = get_option('scantologin_site_id', 0);
        $selfRegistrationAllowed = get_option('scantologin_self_registration_allowed', 'true');
        $demoMode = false;
        $saved = false;
        $errors = array();
        if(isset($_POST['submit'])) {
            $saveResults = $this->admin_page_save($_POST);
            $merchantId = $saveResults['merchantId'];
            $siteId = $saveResults['siteId'];
            $selfRegistrationAllowed = $saveResults['scantologin_self_registration_allowed'];
            $demoMode = false;
            $saved = $saveResults['saved'];
            $errors = $saveResults['errors'];
        }
        ?>
        <div class="wrap">
            <div id="icon-options-general" class="icon32"><br></div>
            <h2>Scan-to-Login Options</h2>
            <?php if($saved) { ?>
            <div class="settings-error updated"><p>Options saved.</p></div>
            <?php } ?>
            <?php if(!empty($errors)) { ?>
            <div class="settings-error updated">
                <?php foreach($errors as $error) { ?>
                <p><?php echo $error ?></p>
                <?php } ?>
            </div>
            <?php } ?>
            <form method="post" action="">
                <h3>Please enter the merchant and site ID obtained.</h3>
                <table>
                    <tr>
                        <td style="width: 200px;">Merchant ID</td>
                        <td><input type="text" name="scantologin_merchant_id" value="<?php echo $merchantId ?>" /></td>
                    </tr>
                    <tr>
                        <td>Site ID</td>
                        <td><input type="text" name="scantologin_site_id" value="<?php echo $siteId ?>" /></td>
                    </tr>
                    <tr>
                        <td style="padding-top: 3px;">Allow any user to register</td>
                        <td>
                            <input <?php if($selfRegistrationAllowed === 'true') { ?>checked="checked"<?php } ?> style="margin: 2px 0 0 2px;" type="checkbox" name="scantologin_self_registration_allowed" value="true" />
                        </td>
                    </tr>
                </table>
                <p><a href="#" id="scantologin-show-advanced-options" style="display:none;">Show advanced options</a></p>
                <div id="scantologin-advanced-options" style="background: #f3f3f3; width: 350px; padding: 1px 10px 10px 10px; display: none;">
                    <h3>Advanced options</h3>
                    <table>
                        <tr>
                            <td style="width: 200px;">Demo mode</td>
                            <td>
                                <input <?php if($demoMode === 'true') { ?>checked="checked"<?php } ?> type="checkbox" name="scantologin_demo_mode" value="true" />
                            </td>
                        </tr>
                    </table>
                </div>
                <script>
                    (function($){
                        $(function(){
                            $('#scantologin-show-advanced-options').on('click', function() {
                               $('#scantologin-advanced-options').show(); 
                               return false;
                            });
                        });
                    })(jQuery);
                </script>
                <p class="submit">
                    <input type="submit" name="submit" id="submit" class="button button-primary" value="Save Changes"/>
                </p>
            </form>
        </div>
        <?php
    }
}

$scantologin = new Scantologin();
add_action('wp_enqueue_scripts', array($scantologin, 'enqueue_scripts'));
add_action('login_form', array($scantologin, 'enqueue_scripts'));
add_action('init', array($scantologin, 'hijack'));
add_action('admin_menu', array($scantologin, 'add_admin_menu'));
